#
# spec file for package xfce4-mpc-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.16.0
%define plugin mpc
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        0.5.5
Release:        1.1
Summary:        MPD Client Plugin for the Xfce Panel
License:        ISC
Group:          System/GUI/XFCE
URL:            https://goodies.xfce.org/projects/panel-plugins/xfce4-mpc-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/0.5/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.60.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libmpd) >= 0.12
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.16.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Mpc plugin is a simple Music Player Daemon client which can control
playback and show the currently playing song.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libmpc.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS README
%license COPYING
%{_libdir}/xfce4/panel/plugins/libmpc.so
%{_datadir}/xfce4/panel/plugins/xfce4-mpc-plugin.desktop

%files lang -f %{name}.lang

%changelog
* Mon Jan  6 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.5
  * Revert "build: Use #ifdef instead of #if"
* Sun Dec 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.4
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * I18n: Update po/LINGUAS list
  * Add Single property toggle in context menu
  * Remove dead code
  * build: Use #ifdef instead of #if
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Get rid of intltool
  * restore changelog history dropped in ca817cd2
  * Translation Updates
* Sat Apr 29 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.3
  * Fix typos
  * Translate more strings (Fixes #8)
  * Fix translated strings (Fixes #5)
  * Remove deprecated project files
  * build: Fix compiler warnings
  * Fix translated string (Fixes #4)
  * Revert "Remove deprecated project files"
  * Update copyright year
  * Remove deprecated project files
  * Update Makefile.am
  * Fix strings if song data is not available (#9)
  * build: Add GLib requirement
  * build: Fix autotools warnings
  * Use "logo-icon-name" instead of "logo" in about dialog
  * build: Fix intltool lock file problem during make distcheck
  * stream can be toggled from right-click menu
  * hide contextual menu 'stream' entry if streaming_appl isnt
    configured/set
  * add a new 'stream' checkbox to contextual menu
  * add mpc_stream_toggled callback
  * add mpc_stop_streaming method
  * use g_spawn_async instead of xfce_spawn_on_screen_with_child_watch
    to spawn the streaming appl
  * make sure error isnt NULL before dereferencing it
  * launch the streaming client when clicking on play
  * add mpc_launch_streaming() method
  * Allow to configure a 'streaming command'
  * use xfce_spawn_command_line() instead of deprecated
    xfce_spawn_command_line_on_screen()
  * Bump copyright year
  * Fix compilation warnings
  * autoconf: Some updates
  * Add basic GitLab pipeline
  * Update URLs from goodies.x.o to docs.x.o
  * Translation Updates
- Remove _service file
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Wed Aug 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.5.2
  * fix crash when parsing MPD 0.21 outputs response in some cases
    (bxo#15415)
  * Translation updates
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omit Changelog
- Move COPYING under %%license macro
* Wed Jan 30 2019 maurizio.galli@gmail.com
- update to 0.5.1
  * fix a long-standing crasher when using multiple outputs
  * improve icon sizing on 4.13 panel
  * improve spacing in settings dialog (bxo#14671)
  * allow %%file%% in format_song_display (bxo#12973)
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to version 0.5.0
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
  - fix changing volume via mousewheel
  - fix icon flickering on mousehover
  - properly resize button/image on set_size event
* Wed Mar  4 2015 gber@opensuse.org
- update to version 0.4.5
  - send Play/Stop/Next/Previous command to MPD
  - decrease/increase volume using the mouse wheel
  - show the current volume, status and title as a tooltip when
    passing the mouse over the plugin
  - show a simple playlist window upon middle-click, permitting to
    select a track to play
  - configurable MPD host/port/password
  - toggles repeat/random features in the right-click menu
* Sun Jul  1 2012 gber@opensuse.org
- update to version 0.4.4
  - better compliance with the panel plugin HIG
  - fix wrong fr translation
* Mon May 14 2012 gber@opensuse.org
- update to version 0.4.3
  - compile the plugin as a module
  - fix xfce4-panel 4.9 detection
  - improve look on multirow panels
* Fri Apr 20 2012 gber@opensuse.org
- corrected license
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- split off -lang subpackage
* Thu Feb 16 2012 gber@opensuse.org
- revert xfce4-panel-plugin-mpc-fix-installation-locations.patch
  %%{_datadir}/xfce4/panel/plugins and
  %%{_libdir}/xfce4/panelr/-plugins are preferred by upstream
* Sun Feb 12 2012 gber@opensuse.org
- update to version 0.4.0
  - migrated from libxfcegui4 to libxfce4ui
  - improved icon sizing/naming
  - icons names are taken from the icon-naming-spec
  - buttons are properly displayed/resized when the panel is
    resized or switched to vertical, or the frame is toggled on/off
  - background is now 'transparent'
- added xfce4-panel-plugin-mpc-fix-installation-locations.patch in
  order to install the plugin executable into
  %%{_libexecdir}/xfce4/panel-plugins and the desktop file into
  %%{_datadir}/xfce4/panel-plugins to be consistent with all other
  plugins
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
